EncodeOptions

Struct EncodeOptions 

pub struct EncodeOptions<'a> { /* private fields */ }
Options that can be specified when encoding a component or a module to customize what the final binary looks like.

Methods such as Module::encode, Wat::encode, and Component::encode will use the default options.

Implementations

Source

impl<'a> EncodeOptions<'a>

pub fn new() -> EncodeOptions<'a>

Creates a new set of default encoding options.

pub fn encode_module(&self, module: &mut Module<'_>) -> Result<Vec<u8>, Error>

Encodes the given Module with these options.

For more information see Module::encode.

pub fn encode_component( &self, component: &mut Component<'_>, ) -> Result<Vec<u8>, Error>

Available on crate feature component-model only.

Encodes the given Component with these options.

For more information see Component::encode.

pub fn encode_wat(&self, wat: &mut Wat<'_>) -> Result<Vec<u8>, Error>

Encodes the given Wat with these options.

For more information see Wat::encode.