pub struct Names<'a> { /* private fields */ }Expand description
Representation of the results of name resolution for a module.
This structure is returned from the
Module::resolve function and can be used
to resolve your own name arguments if you have any.
Implementations
Sourceimpl<'a> Names<'a>
impl<'a> Names<'a>
Sourcepub fn resolve_func(&self, idx: &mut Index<'a>) -> Result<(), Error>
pub fn resolve_func(&self, idx: &mut Index<'a>) -> Result<(), Error>
Resolves idx within the function namespace.
If idx is a Num, it is ignored, but if it’s an Id then it will be
looked up in the function namespace and converted to a Num. If the
Id is not defined then an error will be returned.
Sourcepub fn resolve_memory(&self, idx: &mut Index<'a>) -> Result<(), Error>
pub fn resolve_memory(&self, idx: &mut Index<'a>) -> Result<(), Error>
Resolves idx within the memory namespace.
If idx is a Num, it is ignored, but if it’s an Id then it will be
looked up in the memory namespace and converted to a Num. If the
Id is not defined then an error will be returned.